==> pluggable_entity_view_builder-1.0.0.tar.gz: pluggable_entity_view_builder/pluggable_entity_view_builder_example/src/ProcessedTextBuilderTrait.php <==
<?php

namespace Drupal\pluggable_entity_view_builder_example;

use Drupal\Core\Entity\EntityInterface;

/**
 * Trait ProcessedTextBuilderTrait.
 *
 * Helper method for building a Processed text (e.g. a body field).
 */
trait ProcessedTextBuilderTrait {

  /**
   * Build the body of a node.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   * @param string $field
   *   Optional; The name of the field. Defaults to "body".
   *
   * @return array
   *   Render array.
   */
  protected function buildBody(EntityInterface $entity, $field = 'body') {
    $element = $this->buildProcessedText($entity, $field);
    return $this->wrapComponentWithContainer($element, 'content-body');
  }

  /**
   * Build the comments and comment from of a node.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   *
   * @return array
   *   Render array.
   */
  protected function buildComment(EntityInterface $entity) {
    if (empty($entity->comment)) {
      // Comment field doesn't exist.
      return [];
    }

    return $entity->comment->view();
  }

  /**
   * Build a (processed) text of the content.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   * @param string $field
   *   Optional; The name of the field. Defaults to "body".
   * @param bool $summary_or_trimmed
   *   Optional; If TRUE then the "summary or trimmed" formatter will be used.
   *   Defaults to FALSE.
   *
   * @return array
   *   Render array.
   */
  protected function buildProcessedText(EntityInterface $entity, $field = 'body', $summary_or_trimmed = FALSE) {
    if (empty($entity->{$field}) || $entity->{$field}->isEmpty()) {
      // Field doesn't exist, or empty.
      return [];
    }

    $options = ['label' => 'hidden'];

    if ($summary_or_trimmed) {
      $options['type'] = 'text_summary_or_trimmed';
    }

    $element = [
      '#theme' => 'pluggable_entity_view_builder_example_content__body',
      '#content' => $entity->get($field)->view($options),
    ];

    return $element;
  }

}

==> pluggable_entity_view_builder-1.1.3.tar.gz: pluggable_entity_view_builder/pluggable_entity_view_builder_example/src/ProcessedTextBuilderTrait.php <==
<?php

namespace Drupal\pluggable_entity_view_builder_example;

use Drupal\Core\Entity\EntityInterface;
use Drupal\pluggable_entity_view_builder\ElementWrapTrait;

/**
 * Trait ProcessedTextBuilderTrait.
 *
 * Helper method for building a Processed text (e.g. a body field).
 */
trait ProcessedTextBuilderTrait {

  use ElementWrapTrait;

  /**
   * Build the body of a node.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   * @param string $field
   *   Optional; The name of the field. Defaults to "body".
   *
   * @return array
   *   Render array.
   */
  protected function buildBody(EntityInterface $entity, $field = 'body') {
    $element = $this->buildProcessedText($entity, $field);
    return $this->wrapElementWithContainer($element, 'content-body');
  }

  /**
   * Build the comments and comment from of a node.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   *
   * @return array
   *   Render array.
   */
  protected function buildComment(EntityInterface $entity) {
    if (empty($entity->comment)) {
      // Comment field doesn't exist.
      return [];
    }

    return $entity->comment->view();
  }

  /**
   * Build a (processed) text of the content.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   * @param string $field
   *   Optional; The name of the field. Defaults to "body".
   * @param bool $summary_or_trimmed
   *   Optional; If TRUE then the "summary or trimmed" formatter will be used.
   *   Defaults to FALSE.
   *
   * @return array
   *   Render array.
   */
  protected function buildProcessedText(EntityInterface $entity, string $field = 'body', bool $summary_or_trimmed = FALSE): array {
    if (empty($entity->{$field}) || $entity->{$field}->isEmpty()) {
      // Field doesn't exist, or empty.
      return [];
    }

    $options = ['label' => 'hidden'];

    if ($summary_or_trimmed) {
      $options['type'] = 'text_summary_or_trimmed';
    }

    return [
      '#theme' => 'pluggable_entity_view_builder_example_body',
      '#content' => $entity->get($field)->view($options),
    ];
  }

}
